@@ -302,6 +302,7 @@ class UPSINFO {
    /* Static items that normally do not change during UPS operation */
    int NomOutputVoltage;           /* Nominal voltage when on batteries */
    int NomInputVoltage;            /* Nominal input voltage */
+   int NomPower;                   /* Nominal power (watts) */
    double nombattv;                /* Nominal batt. voltage -- not actual */
    int extbatts;                   /* number of external batteries attached */
    int badbatts;                   /* number of bad batteries */
@@ -332,7 +333,7 @@ class UPSINFO {
    int stattime;
    int datatime;
    int sysfac;
-   int nettime;                    /* Time interval for slaves to poll master */
+   int polltime;                   /* Time interval to poll the UPS */
    int percent;                    /* shutdown when batt % less than this */
    int runtime;                    /* shutdown when runtime less than this */
    char nisip[64];                 /* IP for NIS */
@@ -364,15 +365,15 @@ class UPSINFO {
 };
 
 
-/*These are needed for commands executed in apcaction.c */
+/*These are needed for commands executed in action.c */
 typedef struct {
-   char *command;
+   const char *command;
    int pid;
 } UPSCOMMANDS;
 
 typedef struct s_cmd_msg {
    int level;
-   char *msg;
+   const char *msg;
 } UPSCMDMSG;
 
 #endif   /* _STRUCT_H */
