@@ -42,7 +42,7 @@ extern int apcsmart_ups_check_state(UPSINFO *ups);
 extern int apcsmart_ups_open(UPSINFO *ups);
 extern int apcsmart_ups_close(UPSINFO *ups);
 extern int apcsmart_ups_setup(UPSINFO *ups);
-extern int apcsmart_ups_program_eeprom(UPSINFO *ups, int command, char *data);
+extern int apcsmart_ups_program_eeprom(UPSINFO *ups, int command, const char *data);
 extern int apcsmart_ups_entry_point(UPSINFO *ups, int command, void *data);
 
 #endif   /* _APCSMART_H */
