@@ -263,7 +263,7 @@ int dumb_ups_read_volatile_data(UPSINFO *ups)
    return stat;
 }
 
-int dumb_ups_program_eeprom(UPSINFO *ups, int command, char *data)
+int dumb_ups_program_eeprom(UPSINFO *ups, int command, const char *data)
 {
 #if 0
    printf(_("This model cannot be configured.\n"));
