@@ -171,67 +171,3 @@ goodout:
 }
 
 #endif                             /* HAVE_NISSERVER */
-
-#if defined(HAVE_WIN32)
-
-#include <windows.h>
-
-extern UPSINFO *core_ups;
-extern int shm_OK;
-
-#define MAX_READ 20000
-
-/* Fill the Events list box with the last events */
-void FillEventsBox(HWND hwnd, int id_list)
-{
-   off_t flen, fpos;
-   ssize_t len;
-   char *buf, *p, *l;
-
-   if (!shm_OK || core_ups->event_fd < 0) {
-      SendDlgItemMessage(hwnd, id_list, LB_ADDSTRING, 0,
-         (LONG) "Events not available");
-      return;
-   }
-
-   /* Get size of file, but read only 20000 bytes at most */
-   flen = lseek(core_ups->event_fd, (off_t) 0, SEEK_END);
-   if (flen > MAX_READ) {
-      fpos = flen - MAX_READ;
-      flen = MAX_READ;
-   } else {
-      fpos = 0;
-   }
-
-   buf = (char *)malloc(flen + 1);
-   lseek(core_ups->event_fd, fpos, SEEK_SET);
-
-   len = read(core_ups->event_fd, buf, flen);
-   lseek(core_ups->event_fd, (off_t) 0, SEEK_END);
-   if (len < 0) {
-      SendDlgItemMessage(hwnd, id_list, LB_ADDSTRING, 0,
-         (LONG) "Events not available");
-      return;
-   }
-
-   buf[len] = 0;
-   len = 0;
-   for (l = p = buf; *p; p++) {
-      if (*p == '\n' || *p == '\r') {
-         *p = 0;
-
-         if (len > 1)
-            SendDlgItemMessage(hwnd, id_list, LB_ADDSTRING, 0, (LONG) l);
-
-         l = p + 1;
-         len = 0;
-      } else {
-         len++;
-      }
-   }
-
-   free(buf);
-   return;
-}
-
-#endif   /* HAVE_WIN32 */
