@@ -27,7 +27,7 @@
 /* Send the full status of the UPS to the client. */
 int output_status(UPSINFO *ups, int sockfd,
    void s_open(UPSINFO *ups),
-   void s_write(UPSINFO *ups, char *fmt, ...),
+   void s_write(UPSINFO *ups, const char *fmt, ...),
    int s_close(UPSINFO *ups, int sockfd))
 {
    char datetime[MAXSTRING];
@@ -419,13 +419,16 @@ int output_status(UPSINFO *ups, int sockfd,
          s_write(ups, "BATTDATE : %s\n", ups->battdat);
 
       if (ups->UPS_Cap[CI_NOMOUTV])
-         s_write(ups, "NOMOUTV  : %03d\n", ups->NomOutputVoltage);
+         s_write(ups, "NOMOUTV  : %03d Volts\n", ups->NomOutputVoltage);
 
       if (ups->UPS_Cap[CI_NOMINV])
-         s_write(ups, "NOMINV   : %03d\n", ups->NomInputVoltage);
+         s_write(ups, "NOMINV   : %03d Volts\n", ups->NomInputVoltage);
 
       if (ups->UPS_Cap[CI_NOMBATTV])
-         s_write(ups, "NOMBATTV : %5.1f\n", ups->nombattv);
+         s_write(ups, "NOMBATTV : %5.1f Volts\n", ups->nombattv);
+
+      if (ups->UPS_Cap[CI_NOMPOWER])
+         s_write(ups, "NOMPOWER : %d Watts\n", ups->NomPower);
 
       if (ups->UPS_Cap[CI_HUMID])
          s_write(ups, "HUMIDITY : %5.1f\n", ups->humidity);
@@ -475,7 +478,7 @@ int stat_close(UPSINFO *ups, int fd)
    return 0;
 }
 
-void stat_print(UPSINFO *ups, char *fmt, ...)
+void stat_print(UPSINFO *ups, const char *fmt, ...)
 {
    va_list arg_ptr;
 
